Keen | Typography
Description: Typography elements

# Customer Relationship Management

New Order

### Typography

Reports

### Heading

You can use HTML headings, `<h1>` through `<h6>` as shown below:

# h1. Heading 1

## h2. Heading 2

### h3. Heading 3

#### h4. Heading 4

##### h5. Heading 5

###### h6. Heading 6

Customize font colors using helper classes, `k-font-success` or `k-font-danger`:

# h1. Heading 1

## h2. Heading 2

### h3. Heading 3

#### h4. Heading 4

##### h5. Heading 5

###### h6. Heading 6

### Text

Basic text font settings:

Example text

Example bold text

Example bolder text

Example boldest text

Example uppercase text

Example lowercase text

Example capitalized text

Example cursive text

Color class helpers:

Example text

Example bold text

Example bolder text

Example boldest text

Example uppercase text

Example lowercase text

Example capitalized text

Example cursive text

### Common Elements

Styling for common inline HTML5 text elements.

You can use the mark tag to highlight text.

This line of text is meant to be treated as deleted text.

This line of text is meant to be treated as no longer accurate.

This line of text is meant to be treated as an addition to the document.

This line of text will render as underlined

This line of text is meant to be treated as fine print.

This line rendered as bold text.

This line rendered as italicized text.

Stylized implementation of HTML’s Abbreviations element:

attr

HTML

Quoting blocks of content:

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.

### Heading

Keen comes with multiple helper classes for heading text. Apply the heading class `k-heading` to any typogaphy element.
Heading Typography
Heading Typography Centered
Heading Typography Right Aligned
Heading Typography SM Spacing
Heading Typography MD Spacing
Heading Typography LG Spacing
Heading Typography XL Spacing
Heading Typography SM Font Size
Heading Typography MD Font Size
Heading Typography LG Font Size
Heading Typography Bold
Heading Typography Thin

### Badges

Basic badges:
4 7 8 11 2 5 5 11 2 5
Badge sizes:
4 7 8 11 2 5 5 11 2 5
4 7 8 11 2 5 5 11 2 5
5 7 A D C E
Square style badges:
4 7 8 11 2 5 5 11 2 5
Outline style badges:
4 7 8 11 2 5 5 11 2 5
4 7 8 11 2 5 5 11 2 5
Inline style badges:
Pending Done Error New Done Info Settled
Pending Done Error New Done Info Settled
Pending Done Error New Done Info Settled
Dot style badges:
Some text goes here as example
Some text goes here as example

### Section

Section Title
Section description text.
Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
Other info text.
Aipiscing ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Aadipiscing elit, sed do eiusmod tempor, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
Other description text.
Aipiscing ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Aadipiscing elit, sed do eiusmod tempor, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.

### Separator

Common use separator elemements:

### Divider

Common use devider elemements:
OR

### Links

Basic link examples

Example link

Example bold link

Example bolder link

Example boldest link

Example uppercase link

State colors

Success state

Warning state

Info state

Danger state

Primary state

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!